@@ -1,4 +1,3 @@
-# coding: utf-8
 require "minitest/autorun"
 require "hoe"
 require "tempfile"
@@ -9,9 +8,16 @@ class Hoe
   end
 end
 
-$rakefile = nil # shuts up a warning in rdoctask.rb
-
 class TestHoe < Minitest::Test
+  def without_plugins
+    old = Hoe.plugins.dup
+    Hoe.plugins.clear
+
+    yield
+  ensure
+    Hoe.plugins.replace old
+  end
+
   def hoe *skips, &b
     @hoe ||= Hoe.spec "blah" do
       developer "author", "email"
@@ -151,6 +157,8 @@ class TestHoe < Minitest::Test
         File.write "README.rdoc", "= blah\n\nhome :: http://blah/"
         File.write "History.rdoc", "=== 1.0"
 
+        hoe = without_plugins { self.hoe }
+
         assert_equal "History.rdoc", hoe.history_file
         assert_equal "README.rdoc", hoe.readme_file
         assert_equal %w[FAQ.rdoc History.rdoc README.rdoc],
@@ -172,6 +180,20 @@ class TestHoe < Minitest::Test
     end
   end
 
+  def test_initialize_intuit__empty
+    Dir.mktmpdir do |path|
+      Dir.chdir path do
+        File.write "README.rdoc", "= blah\n"
+
+        e = assert_raises RuntimeError do
+          hoe
+        end
+
+        assert_match(/wrong format/, e.message)
+      end
+    end
+  end
+
   def test_file_read_utf
     Tempfile.open "BOM" do |io|
       io.write "\xEF\xBB\xBFBOM"
@@ -179,40 +201,21 @@ class TestHoe < Minitest::Test
 
       content = File.read_utf io.path
       assert_equal "BOM", content
-
-      if content.respond_to? :encoding then
-        assert_equal Encoding::UTF_8, content.encoding
-      end
-    end
-  end
-
-  def test_parse_urls_ary
-    ary  = ["* https://github.com/seattlerb/hoe",
-            "* http://docs.seattlerb.org/hoe/",
-            "* http://docs.seattlerb.org/hoe/Hoe.pdf",
-            "* http://github.com/jbarnette/hoe-plugin-examples"].join "\n"
-
-    exp = { "home" => "https://github.com/seattlerb/hoe" }
-    err = /DEPRECATED: Please switch readme to hash format/
-
-    assert_output "", err do
-      assert_equal exp, hoe.parse_urls(ary)
+      assert_equal Encoding::UTF_8, content.encoding
     end
   end
 
   def test_parse_urls_hash
     hash = [
             "home  :: https://github.com/seattlerb/hoe",
-            "rdoc  :: http://docs.seattlerb.org/hoe/",
-            "doco  :: http://docs.seattlerb.org/hoe/Hoe.pdf",
-            "other :: http://github.com/jbarnette/hoe-plugin-examples",
+            "rdoc  :: https://docs.seattlerb.org/hoe/",
+            "doco2 :: https://docs.seattlerb.org/hoe/Hoe.pdf",
+            "other :: https://github.com/jbarnette/hoe-plugin-examples",
            ].join "\n"
 
     exp = {
-      "home"  => "https://github.com/seattlerb/hoe",
-      "rdoc"  => "http://docs.seattlerb.org/hoe/",
-      "doco"  => "http://docs.seattlerb.org/hoe/Hoe.pdf",
-      "other" => "http://github.com/jbarnette/hoe-plugin-examples",
+      "home" => "https://github.com/seattlerb/hoe",
+      "rdoc" => "https://docs.seattlerb.org/hoe/",
     }
 
     assert_equal exp, hoe.parse_urls(hash)
@@ -235,8 +238,6 @@ class TestHoe < Minitest::Test
       make working with file tasks cleaner, easier, and faster.
     EOM
 
-
-
     assert_silent do
       h = Hoe.spec "blah" do
         developer "author", "email"
@@ -251,13 +252,17 @@ class TestHoe < Minitest::Test
     end
 
     desc = mrww_readme.lines[10..11].join.chomp
+    summ = desc.chomp(".")
+    rdoc = "\n\n==== To Install:\n"
+    desc += rdoc
+
     urls = {
       "home" => "https://github.com/seattlerb/makerakeworkwell",
       "rdoc" => "http://docs.seattlerb.org/makerakeworkwell"
     }
 
     assert_equal desc, h.description
-    assert_equal desc, h.summary
+    assert_equal summ, h.summary
     assert_equal urls, h.urls
   end
 
@@ -265,7 +270,7 @@ class TestHoe < Minitest::Test
     h = nil
     nokogiri_readme = <<~EOM
       ## Links
-      
+
       * https://nokogiri.org
       * [Installation Help](https://nokogiri.org/tutorials/installing_nokogiri.html)
       * [Tutorials](https://nokogiri.org/tutorials/toc.html)
@@ -297,6 +302,30 @@ class TestHoe < Minitest::Test
     assert_equal exp, h.urls
   end
 
+  def test_intuit_values_should_be_silent_if_summary_description_and_homepage_are_set
+    h = nil
+    _readme = <<~EOM
+      == this is readme
+
+      == description
+      this is a bogus description
+    EOM
+
+    assert_silent do
+      h = Hoe.spec "blah" do
+        developer "auther", "email"
+        license "MIT"
+        self.homepage = 'http://myhome'
+        self.description = 'this is real description'
+        self.summary = 'this is summary'
+      end
+    end
+
+    assert_equal h.homepage , 'http://myhome'
+    assert_equal h.description , 'this is real description'
+    assert_equal h.summary , 'this is summary'
+  end
+
   def test_metadata
     hash = [
             "home  :: https://github.com/seattlerb/hoe",
@@ -321,6 +350,8 @@ class TestHoe < Minitest::Test
     assert_equal exp, hoe.parse_urls(hash)
   end
 
+  make_my_diffs_pretty!
+
   def test_possibly_better
     t = Gem::Specification::TODAY
 
@@ -331,15 +362,14 @@ class TestHoe < Minitest::Test
     files = File.read("Manifest.txt").split(/\n/)
 
     spec = hoe.spec
+    spec.date = nil # forces Date.today. default switched to 1980 for some reason
 
     urls = {
-      "home"  => "http://www.zenspider.com/projects/hoe.html",
+      "home"  => "https://zenspider.com/projects/hoe.html",
       "code"  => "https://github.com/seattlerb/hoe",
       "bugs"  => "https://github.com/seattlerb/hoe/issues",
-      "rdoc"  => "http://docs.seattlerb.org/hoe/",
-      "doco"  => "http://docs.seattlerb.org/hoe/Hoe.pdf",
+      "doco"  => "https://docs.seattlerb.org/hoe/",
       "clog"  => "https://github.com/seattlerb/hoe/blob/master/History.rdoc",
-      "other" => "http://github.com/jbarnette/hoe-plugin-examples",
     }
 
     assert_equal urls, hoe.urls
@@ -365,9 +395,11 @@ class TestHoe < Minitest::Test
 
     deps = spec.dependencies.sort_by(&:name)
 
+    version = Hoe::VERSION[/\d+\.\d+/]
+
     expected = [
-      ["hoe",  :development, "~> #{Hoe::VERSION.sub(/\.\d+$/, "")}"],
-      ["rdoc", :development, "< 7", ">= 4.0"],
+      ["hoe",  :development, "~> #{version}"],
+      ["rdoc", :development, "< 8", ">= 6.0"],
     ]
 
     assert_equal expected, deps.map { |dep|
@@ -441,14 +473,14 @@ class TestHoe < Minitest::Test
 
   def test_nosudo
     hoe = self.hoe do
-      def system cmd
+      def sh cmd
         cmd
       end
     end
 
-    assert_match(/^(sudo )?(j|maglev-)?gem.*/, hoe.install_gem("foo"))
+    assert_match(/^(sudo )?gem.*/, hoe.install_gem("foo"))
     ENV["NOSUDO"] = "1"
-    assert_match(/^(j|maglev-)?gem.*/, hoe.install_gem("foo"))
+    assert_match(/^gem.*/, hoe.install_gem("foo"))
   ensure
     ENV.delete "NOSUDO"
   end
